X-Git-Url: https://git.rapsys.eu/userbundle/blobdiff_plain/55beb067dbd20e192fb31ca0a5027d678bc4b233..67386c1992816b267b3c482352a6500dd1424e0c:/Entity/Group.php?ds=inline

diff --git a/Entity/Group.php b/Entity/Group.php
index dad79b0..c503b2f 100644
--- a/Entity/Group.php
+++ b/Entity/Group.php
@@ -12,7 +12,7 @@ class Group {
 	/**
 	 * @var string
 	 */
-	protected $role;
+	protected $title;
 
 	/**
 	 * @var \DateTime
@@ -31,44 +31,43 @@ class Group {
 
 	/**
 	 * Constructor
 	 * @param string $role The role name
 	 */
-	public function __construct(string $role) {
-		$this->role = (string) $role;
+	public function __construct(string $title) {
+		$this->title = (string) $title;
 		$this->users = new \Doctrine\Common\Collections\ArrayCollection();
 	}
 
 	/**
-	 * Set role
-	 *
-	 * @param string $role
+	 * Get id
 	 *
-	 * @return User
+	 * @return integer
 	 */
-	public function setRole($role) {
-		$this->role = $role;
-
-		return $this;
+	public function getId() {
+		return $this->id;
 	}
 
 	/**
-	 * Get role
+	 * Set title
 	 *
-	 * @return string
+	 * @param string $title The group name
+	 *
+	 * @return User
 	 */
-	public function getRole() {
-		return $this->role;
+	public function setTitle($title) {
+		$this->title = $title;
+
+		return $this;
 	}
 
 	/**
-	 * Returns a string representation of the role.
-	 *
-	 * @xxx Replace the deprecated "extends \Symfony\Component\Security\Core\Role\Role"
+	 * Get title
 	 *
 	 * @return string
 	 */
-	public function __toString(): string {
-		return $this->role;
+	public function getTitle() {
+		return $this->title;
 	}
 
 	/**
@@ -145,4 +144,22 @@ class Group {
 	public function getUsers() {
 		return $this->users;
 	}
+
+	/**
+	 * Returns a string representation of the group
+	 *
+	 * @return string
+	 */
+	public function __toString(): string {
+		return $this->title;
+	}
+
+	/**
+	 * Get role
+	 *
+	 * @return string
+	 */
+	public function getRole() {
+		return 'ROLE_'.strtoupper($this->title);
+	}
 }
@@ -31,44 +31,43 @@ class Group {
 	/**
 	 * Constructor
-	 * @param string $role The role name
+	 *
+	 * @param string $title The group name
 	 */